@@ -27,8 +27,8 @@ class YouTubeDataService(object):
     ytService = gdata.youtube.service.YouTubeService()
     ytService.email = ""
     ytService.password = ""
-    ytService.source = "Ytube"
-    ytService.developer_key = "AI39si6YT7uxB9Zwrj1xW86FNKrUC92lYrPhoh6BwkcBzb_7E9Kiq9-HlqWC_DKvcaE6hq9r_wHjoMoUQAG70fTCUYmcKb4RcQ"
+    ytService.source = "cuteTube"
+    ytService.developer_key = "AI39si6x9O1gQ1Z_BJqo9j2n_SdVsHu1pk2uqvoI3tVq8d6alyc1og785IPCkbVY3Q5MFuyt-IFYerMYun0MnLdQX5mo2BueSw"
     stdHeaders = {
     'User-Agent': 'Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.8) Gecko/20100723 Firefox/3.6.8',
     'Accept-Charset': 'ISO-8859-1,utf-8;q=0.7,*;q=0.7',
@@ -140,10 +140,14 @@ class YouTubeDataService(object):
         """
         Creates a new playlist using the title and description arguments.
         """
-        new_playlistentry = YouTubeDataService.ytService.AddPlaylist(playlistTitle, playlistDescription, private)
-        if isinstance(new_playlistentry, gdata.youtube.YouTubePlaylistEntry):
-            return True
-        return False
+        try:
+            YouTubeDataService.ytService.AddPlaylist(playlistTitle, playlistDescription, private)
+            result = True
+        except gdata.service.Error, e:
+            result = e.args[0].get("body")
+            CutetubeLog.logException(e)
+        return result
+
 
     @staticmethod
     def addVideoToPlaylist(playlistId, videoId):
@@ -168,8 +172,8 @@ class YouTubeDataService(object):
         return result
 
     @staticmethod
-    def updatePlaylistVideo(playlist_uri, playlistentryId, newVideoTitle, newVideoDescription, newPosition):
-        YouTubeDataService.ytService.UpdatePlaylistVideoEntryMetaData(playlist_uri, playlistentryId, newVideoTitle, newVideoDescription, newPosition)
+    def updatePlaylistVideo(playlistId, playlistVideoId, newVideoTitle, newVideoDescription, newPosition):
+        YouTubeDataService.ytService.UpdatePlaylistVideoEntryMetaData(playlistId, playlistVideoId, newVideoTitle, newVideoDescription, newPosition)
 
     @staticmethod
     def updatePlaylist(playlistId, newPlaylistTitle, newPlaylistDescription, private):
@@ -187,7 +191,7 @@ class YouTubeDataService(object):
         return result
 
     @staticmethod
-    def getVideoEntry(videoId, apiVersion=1):
+    def getVideoEntry(videoId, apiVersion = 1):
         try:
             videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(video_id = videoId, api_version = apiVersion)
         except:
@@ -224,18 +228,19 @@ class YouTubeDataService(object):
         return thumbnail
 
     @staticmethod
-    def updateVideo(video_uri, newVideoTitle, newVideoDescription):
-        video = YouTubeDataService.ytService.GetYouTubeVideoEntry(video_uri)
+    def updateVideo(videoId, newVideoTitle, newVideoDescription):
+        video = YouTubeDataService.getVideoEntry(videoId)
         video.media.title.text = newVideoTitle
         video.media.description.text = newVideoDescription
+        video.link.append(atom.Link(rel='edit', href='http://gdata.youtube.com/feeds/api/users/%s/uploads/%s' % (YouTubeDataService.currentUser, videoId.split("/")[-1])))
         YouTubeDataService.ytService.UpdateVideoEntry(video)
 
     @staticmethod
-    def deleteVideo(video_uri):
+    def deleteVideo(videoId):
         """
         Deletes the video from the user's uploads.
         """
-        videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(video_uri)
+        videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(videoId)
         YouTubeDataService.ytService.DeleteVideoEntry(videoEntry)
 
     @staticmethod
